@@ -1,6 +1,6 @@
 #!/bin/bash
 # Trevor SANDY
-# Last Update September 19, 2025
+# Last Update October 22, 2025
 # Copyright (C) 2022 - 2025 by Trevor SANDY
 #
 # This script is run from a Docker container call
@@ -130,6 +130,8 @@ export WD=$PWD
 export CI=${CI:-true}
 export OBS=${OBS:-false}
 export GITHUB=${GITHUB:-true}
+export GITHUB_REF=${GITHUB_REF:-}
+export GITHUB_SHA=${GITHUB_SHA:-}
 export DOCKER=${DOCKER:-true}
 export LP3D_NO_DEPS=${LP3D_NO_DEPS:-true}
 export LP3D_LOG_PATH=${LP3D_LOG_PATH:-/out}
@@ -149,6 +151,8 @@ fi
 [ -n "${LP3D_ARCH}" ] && Info "BUILD ARCH.........${LP3D_ARCH}" || :
 [ -n "${CI}" ] && Info "CI.................${CI}" || :
 [ -n "${GITHUB}" ] && Info "GITHUB.............${GITHUB}" || :
+[ -n "${GITHUB_REF}" ] && Info "GITHUB_REF.........${GITHUB_REF}" || :
+[ -n "${GITHUB_SHA}" ] && Info "GITHUB_SHA.........${GITHUB_SHA}" || :
 [ -n "${LP3D_PUBLISH_RENDERERS}" ] && Info "PUBLISH RENDERERS..${LP3D_PUBLISH_RENDERERS}" || :
 [ -n "${LP3D_APPIMAGE}" ] && Info "APPIMAGE...........${LP3D_APPIMAGE}" || :
 if [ "${LP3D_APPIMAGE}" = "true" ]; then
@@ -250,22 +254,24 @@ else
 fi
 
 # For Docker build, check if there is a tag after the last commit
-if [ "${DOCKER}" = "true" ]; then
-  # Setup git command
-  GIT_CMD="git --git-dir ${WD}/.git --work-tree ${WD}"
+if [ -d "${WD}/.git" ]; then
+   # Setup git command
+   LP3D_GIT="git --git-dir ${WD}/.git --work-tree ${WD}"
+fi
+if [[ -n "${LP3D_GIT}" && "$DOCKER" = "true" ]]; then
   # Pull latest
-  [ "${CI}" = "true" ] && ${GIT_CMD} pull || :
+  [ "${CI}" = "true" ] && ${LP3D_GIT} pull >/dev/null 2>&1 || :
   #1. Get the latest version tag - check across all branches
-  BUILD_TAG="$(${GIT_CMD} describe --tags --match v* "$(${GIT_CMD} rev-list --tags --max-count=1)" 2> /dev/null)"
+  BUILD_TAG="$(${LP3D_GIT} describe --tags --match v* "$(${LP3D_GIT} rev-list --tags --max-count=1)" 2> /dev/null)"
   if [ -n "${BUILD_TAG}" ]; then
     #2. Get the tag datetime
-    BUILD_TAG_TIME=$(${GIT_CMD} log -1 --format=%ai $BUILD_TAG 2> /dev/null)
+    BUILD_TAG_TIME=$(${LP3D_GIT} log -1 --format=%ai $BUILD_TAG 2> /dev/null)
     #3. Get the latest commit datetime from the build branch
-    GIT_COMMIT_TIME=$(${GIT_CMD} log -1 --format=%ai 2> /dev/null)
+    GIT_COMMIT_TIME=$(${LP3D_GIT} log -1 --format=%ai 2> /dev/null)
     #4. If tag is newer than commit, check out the tag
     if [[ "$(date -d "${GIT_COMMIT_TIME}" +%s)" -lt "$(date -d "${BUILD_TAG_TIME}" +%s)" ]]; then
       Info "2a. checking out build tag ${BUILD_TAG}..."
-      ${GIT_CMD} checkout -qf ${BUILD_TAG}
+      ${LP3D_GIT} checkout -qf ${BUILD_TAG}
     fi
   fi
 fi
@@ -450,7 +456,7 @@ if [[ -z "${LP3D_AI_BUILD_TOOLS}" ]]; then
   fi
   SaveAppImageSetupProgress
 else
-  cd "${WD}/" || exit 1
+  cd "${WD}" || exit 1
   [ ! -d bin ] && mkdir bin || :
   export PATH="${WD}/bin":"${PATH}"
   CommandArg=-version
@@ -608,14 +614,19 @@ fi
 # Build AppImage
 cd "${AppDirBuildPath}" || exit 1
 Info && Info "Building AppImage from AppDirBuildPath: ${AppDirBuildPath}..."
-renderers=$(find ./opt -type f);
-for r in $renderers; do executables="$executables -executable=$r" && Info "Set executable $executables"; done;
+renderers=$(find ${AppDirBuildPath}/usr/bin/lpub3d/3rdParty -type f);
+for r in $renderers; do executables="$executables -executable=$r"; done;
+Info "Renderer executables: $executables"
 unset QTDIR; unset QT_PLUGIN_PATH # no longer needed, superceded by AppRun
 export VERSION="$LP3D_VERSION"    # used to construct the file name
 ./linuxdeployqt ./usr/share/applications/*.desktop $executables -bundle-non-qt-libs -verbose=2
 if [[ -z "${LP3D_AI_BUILD_TOOLS}" ]]; then
   ./linuxdeployqt ./usr/share/applications/*.desktop -appimage -verbose=2
   AppImage=$(ls LPub3D*.AppImage)  # name with full path
+  if [ ! -f "$AppImage" ]; then
+    Error Build AppImage FAILED
+    exit 9
+  fi  
 else
   # lpub3d.desktop
   [ -f "./usr/share/applications/lpub3d.desktop" ] && \
@@ -678,7 +689,7 @@ else
   else
    Error "File ./bin/$a was not found"
   fi
-  
+
   # set path to AppDir
   cd ${AppDirBuildPath} || exit 1
 
@@ -794,7 +805,7 @@ if [[ -f "${AppImage}" ]]; then
     Error "AppImage build completed but the .sha512 file was not found."
   fi
 else
-  Error "${AppImage} build FAILED. File not found."
+  Error "AppImage file not found. ${AppImage} build FAILED."
   exit 8
 fi
 
@@ -805,9 +816,8 @@ cd "${WD}" || exit 1
 AppImageCheck=$(find ./ -name ${AppImagePatched} -type f) || \
 AppImageCheck=$(find ./ -name ${AppImageName} -type f)
 if [[ -f "${AppImageCheck}" ]]; then
-  export SOURCE_DIR=${WD}
-  export LP3D_BUILD_OS="appimage"
-  export LP3D_CHECK_STATUS="--version --app-paths"
+  SOURCE_DIR=${WD}
+  LP3D_CHECK_STATUS="--version --app-paths"
   mkdir -p appImage_Check && cp -f ${AppImageCheck} appImage_Check/${AppImageName} && \
   Info "$(ls ./appImage_Check/*.AppImage) copied to check folder."
   if [[ -z "$(which fusermount)" || -n "${LP3D_AI_EXTRACT_PAYLOAD}" ]]; then
@@ -815,25 +825,29 @@ if [[ -f "${AppImageCheck}" ]]; then
     ) >$p.out 2>&1 && rm -f $p.out
     if [[ ! -f $p.out ]]; then
       Info "Build check extracted AppImage payload..."
+      LP3D_BUILD_OS=
       LPUB3D_EXE="appImage_Check/squashfs-root/usr/bin/lpub3d${LP3D_VER_MAJOR}${LP3D_VER_MINOR}"
     else
-      Error "Extract ${AppImageName} FAILED"
+      Error "Build check cannot proceed. Extract ${AppImageName} FAILED"
       tail -80 $p.out
     fi
   else
     Info "Build check AppImage..."
+    LP3D_BUILD_OS="appimage"
     LPUB3D_EXE="appImage_Check/${AppImageName}"
+    LP3D_RENDERER_DIR=${AppDirBuildPath}/usr/bin/lpub3d/3rdParty
+    test -f ${LP3D_RENDERER_DIR}/ldview-4.6/bin/ldview && LDVIEW_EXE=ldview || :
+    test -f ${LP3D_RENDERER_DIR}/ldglite-1.3/bin/ldglite && LDGLITE_EXE=ldglite || :
+    test -f ${LP3D_RENDERER_DIR}/lpub3d_trace_cui-3.8/bin/lpub3d_trace_cui && POVRAY_EXE=lpub3d_trace_cui || :    
   fi
   if [[ -n "${LPUB3D_EXE}" ]]; then
-    export LPUB3D_EXE
     set +x && source ${SOURCE_DIR}/builds/check/build_checks.sh && set -x
   fi
   if [[ "${AppImageCheck}" == *".patched"* ]]; then
     rm -fr ${AppImageCheck}
   fi
 else
-  Error "${AppImageCheck} not found, the build check cannot proceed."
-  exit 8
+  Error "Build check cannot proceed. ${AppImageCheck} not found."
 fi
 
 # Move AppImage build content to output
@@ -850,7 +864,7 @@ if [[ ! "${BUILD_OPT}" = "verify" ]]; then
   ) >$t.out 2>&1 && rm $t.out
   [[ -f $t.out ]] && \
   echo && Error "Move build package to output failed." && \
-  tail -80 $t.out || echo "Ok." 
+  tail -80 $t.out || echo "Ok."
 fi
 
 exit 0
