@@ -1,6 +1,6 @@
 #!/bin/bash
 # Trevor SANDY
-# Last Update September 21, 2025
+# Last Update October 18, 2025
 # Copyright (C) 2016 - 2025 by Trevor SANDY
 #
 # This script is automatically executed by qmake from mainApp.pro
@@ -13,6 +13,8 @@
 #
 # Optional argument:
 # _EXPORT_CONFIG_ONLY_ Do not update config files. Only export variables
+#
+# env _PRO_FILE_PWD_=$PWD/mainApp _EXPORT_CONFIG_ONLY_=1 OBS=false ./builds/utilities/update-config-files.sh
 
 LP3D_ME="$(basename "$(test -L "$0" && readlink "$0" || echo "$0")")"
 [ "${LP3D_ME}" != "update-config-files.sh" ] && SOURCED="true" || SOURCED="false"
@@ -30,9 +32,16 @@ LP3D_CALL_DIR=`pwd`
 LP3D_OS=`uname`
 LP3D_GIT_DEPTH=150000
 LP3D_CMD_COUNT=0
+LP3D_RELEASE_BUILD=0
 LP3D_APP=${LPUB3D:-lpub3d-ci}
 
-[ -n "$1" ] && LP3D_PWD=$1 || LP3D_PWD=${_PRO_FILE_PWD_}
+[[ -n "$1" && "$1" != "Update" ]] && LP3D_PWD=$1 || LP3D_PWD=${_PRO_FILE_PWD_}
+if [ "$LP3D_PWD" = "" ]
+then
+    Info "ERROR: Did not receive required argument #1 or env variable _PRO_FILE_PWD_"
+    Info "$([ "${SOURCED}" = "true" ] && echo update-config-files || echo $LP3D_ME) terminated!"
+    exit 1
+fi
 
 [[ -n "$7" && "${SOURCED}" == "false" ]] && lp3d_option="arguments" || lp3d_option="queries"
 
@@ -63,24 +72,13 @@ realpath() {
   echo "$REALPATH_"
 }
 
-# Change these accordingly when respective config files are modified
-if [ "$OBS" = "true" ]
-then
-    UPDATE_OBS_ALL_DEPS=Yes
-    LP3D_CONFIG_DIR=$(realpath "$LP3D_PWD/../builds/linux/obs/alldeps")
-else
-    UPDATE_OBS_ALL_DEPS=No
-    LP3D_CONFIG_DIR=$(realpath "$LP3D_PWD/../builds/linux/obs")
-fi
+# Always update OBS config files unless OBS specified as false
+[ "$LP3D_OS" = Darwin ] && OBS=false || :
+[ "$OBS" = "false" ] && UPDATE_OBS_ALL_DEPS=No || UPDATE_OBS_ALL_DEPS=Yes
+LP3D_OBS_DEPS_DIR=$(realpath "$LP3D_PWD/../builds/linux/obs")
+LP3D_OBS_ALL_DEPS_DIR=$(realpath "$LP3D_PWD/../builds/linux/obs/alldeps")
 LP3D_UTIL_DIR=$(realpath "$LP3D_PWD/../builds/utilities")
 
-if [ "$LP3D_PWD" = "" ] && [ "${_PRO_FILE_PWD_}" = "" ]
-then
-    Info "Error: Did not receive required argument _PRO_FILE_PWD_"
-    Info "$([ "${SOURCED}" = "true" ] && echo update-config-files || echo $LP3D_ME) terminated!"
-    exit 1
-fi
-
 if [ "${SOURCED}" != "true" ]
 then
     # logging stuff
@@ -94,28 +92,29 @@ then
     exec 2> >(tee -a ${LOG} >&2)
 fi
 
-#Info "   DEBUG INPUT ARGS \$0 [$0], \$1 [$1], \$2 [$2], \$3 [$3], \$4 [$4], \$5 [$5], \$6 [$6], \$7 [$7], \$8 [$8]"
 if [ "${lp3d_option}" = "queries" ]
 then
-    cd "$(realpath $LP3D_PWD/..)"
-    if [ "${CI}" = "true" ];
+    cd ${LP3D_PWD}/..
+    if [ ! -d "${PWD}/.git" ]
     then
-        # Update refs and tags and populate committer email, name
+        Info "ERROR - No .git folder found at ${PWD}/.git"
+        exit 1
+    fi
+    if [ "$1" = "Update" ]
+    then
+        # Update refs and tags
         Info "$((LP3D_CMD_COUNT += 1)). update git tags and capture version info using git queries"
-        if [ ! -d ".git" ]; then
-            Info "ERROR - No .git folder in $PWD"
-        fi
-        if [ -n "$TRAVIS" ]; then
-            LP3D_BRANCH=${TRAVIS_BRANCH}
-            LP3D_COMMIT=${TRAVIS_COMMIT}
-        elif [ -n "$GITHUB" ]; then
+        if [ -n "${GITHUB}" ]
+        then
             LP3D_BRANCH=${GITHUB_REF}
             LP3D_COMMIT=${GITHUB_SHA}
+        elif [ -n "${TRAVIS}" ]
+        then
+            LP3D_BRANCH=${TRAVIS_BRANCH}
+            LP3D_COMMIT=${TRAVIS_COMMIT}
         fi
         git fetch -qfup --depth=${LP3D_GIT_DEPTH} origin +${LP3D_BRANCH} +refs/tags/*:refs/tags/* >/dev/null 2>&1
         git checkout -qf ${LP3D_COMMIT} >/dev/null 2>&1
-        lp3d_git_ver_author="$(git log -1 ${LP3D_COMMIT} --pretty="%aN")" >/dev/null 2>&1
-        lp3d_git_ver_committer_email="$(git log -1 ${LP3D_COMMIT} --pretty="%cE")" >/dev/null 2>&1
     else
         Info "$((LP3D_CMD_COUNT += 1)). capture version info using git queries"
     fi
@@ -124,28 +123,39 @@ then
     lp3d_git_ver_tag_short=`git describe --tags --match v* --abbrev=0` >/dev/null 2>&1
     lp3d_git_ver_commit_count=`git rev-list --count HEAD` >/dev/null 2>&1
     lp3d_git_ver_sha_hash_short=`git rev-parse --short HEAD` >/dev/null 2>&1
-    cd "${LP3D_CALL_DIR}"
+    last_commit_sha=`git rev-parse HEAD` >/dev/null 2>&1
+    last_annotated_tag=`git describe --abbrev=0` >/dev/null 2>&1
+    last_annotated_tag_sha=`git rev-list -n 1 ${last_annotated_tag}` >/dev/null 2>&1
+    lp3d_git_ver_author=`git log -1 ${lp3d_git_ver_sha_hash_short} --pretty="%aN"` >/dev/null 2>&1
+    lp3d_git_ver_committer_email=`git log -1 ${lp3d_git_ver_sha_hash_short} --pretty="%cE"` >/dev/null 2>&1
     lp3d_ver_tmp=${lp3d_git_ver_tag_long#*-}                                          # remove everything before and including "-"
     lp3d_revision_=${lp3d_ver_tmp%-*}                                                 # remove everything after and including "-"
     lp3d_ver_tmp=${lp3d_git_ver_tag_short//./" "}                                     # replace . with " "
     lp3d_version_=${lp3d_ver_tmp/v/}                                                  # replace v with ""
     lp3d_ver_tmp=${lp3d_version_#*_}                                                  # remove everything before and including "_" if exist
-    if test -z "$lp3d_git_build_type"; then LP3D_BUILD_TYPE="Continuous"; else LP3D_BUILD_TYPE="Release"; fi
-    if test "$lp3d_ver_tmp" != "$lp3d_version_"; then lp3d_suffix=${lp3d_ver_tmp}; fi # check if ver_tmp not same as version_ - suffix exist
-    if test -n "$lp3d_suffix"; then lp3d_version_=${lp3d_version_%_*}; fi             # remove everything after and including "_" - suffix exist
-    if test -n "$lp3d_git_ver_author"; then LP3D_AUTHOR_NAME=${lp3d_git_ver_author}; else LP3D_AUTHOR_NAME=`echo $USER`; fi
-    if test -n "$lp3d_git_ver_committer_email"; then LP3D_COMMITTER_EMAIL=${lp3d_git_ver_committer_email}; else LP3D_COMMITTER_EMAIL=trevor.sandy@gmail.com; fi
+    if test -z "${lp3d_git_build_type}"; then LP3D_BUILD_TYPE="Continuous"; else LP3D_BUILD_TYPE="Release"; fi
+    if test -z "${LP3D_COMMIT}"; then LP3D_COMMIT=${lp3d_git_ver_sha_hash_short}; fi
+    if test "${lp3d_ver_tmp}" != "${lp3d_version_}"; then lp3d_suffix=${lp3d_ver_tmp}; fi # check if ver_tmp not same as version_ - suffix exist
+    if test -n "${lp3d_suffix}"; then lp3d_version_=${lp3d_version_%_*}; fi             # remove everything after and including "_" - suffix exist
+    if test "${last_commit_sha}" = "${last_annotated_tag_sha}"; then LP3D_RELEASE_BUILD=1; fi # set release build when the last commit is an annotated tag
     LP3D_VERSION_INFO=${lp3d_version_}" "${lp3d_revision_}" "${lp3d_git_ver_commit_count}" "${lp3d_git_ver_sha_hash_short}
-else
-    Info "$((LP3D_CMD_COUNT += 1)). capture version info using input arguments"
+elif [ "${lp3d_option}" = "arguments" ]; then
+    #Info "   DEBUG INPUT ARGS \$0 [$0], \$1 [$1], \$2 [$2], \$3 [$3], \$4 [$4], \$5 [$5], \$6 [$6], \$7 [$7], \$8 [$8], \$9 ["$9"], \$10 ["${10}"], \$11 [${11}]"
+    Info "$((LP3D_CMD_COUNT += 1)). capture version info using $# input arguments"
     LP3D_BUILD_TYPE="Default"
-    if test -n "$8"; then lp3d_suffix=$8; fi
     LP3D_VERSION_INFO=$2" "$3" "$4" "$5" "$6" "$7
+    LP3D_COMMIT=$7
+    LP3D_RELEASE_BUILD=$8
+    lp3d_git_ver_author="$9"
+    lp3d_git_ver_committer_email="${10}"
+    if test -n "${11}"; then lp3d_suffix=${11}; fi
 fi
+if test -n "$lp3d_git_ver_author"; then LP3D_AUTHOR_NAME=${lp3d_git_ver_author}; else LP3D_AUTHOR_NAME=`echo $USER`; fi
+if test -n "$lp3d_git_ver_committer_email"; then LP3D_COMMITTER_EMAIL=${lp3d_git_ver_committer_email}; else LP3D_COMMITTER_EMAIL=undefined; fi
 if test -n "$lp3d_suffix"; then
     LP3D_VERSION_INFO="$LP3D_VERSION_INFO $lp3d_suffix"
 fi
-#         1 2 3  4  5   6
+#         1 2  3  4   5       6
 # format "2 0 20 17 663 410fdd7"
 read LP3D_VER_MAJOR LP3D_VER_MINOR LP3D_VER_PATCH LP3D_VER_REVISION LP3D_VER_BUILD LP3D_VER_SHA_HASH LP3D_VER_SUFFIX THE_REST <<< ${LP3D_VERSION_INFO//'"'}
 LP3D_APP_VER_SUFFIX=${LP3D_VER_MAJOR}${LP3D_VER_MINOR}
@@ -155,6 +165,8 @@ LP3D_APP_VERSION=${LP3D_VERSION}"."${LP3D_VER_BUILD}
 LP3D_APP_VERSION_LONG=${LP3D_VERSION}"."${LP3D_VER_REVISION}"."${LP3D_VER_BUILD}_${LP3D_BUILD_DATE}
 LP3D_APP_VERSION_TAG="v"${LP3D_VERSION}
 
+cd "${LP3D_CALL_DIR}"
+
 Info "   LP3D_BUILD_TYPE........${LP3D_BUILD_TYPE}"
 Info "   LP3D_SOURCE_DIR........${LP3D_SOURCE_DIR}"
 Info "   LP3D_APPLICATION_NAME..${LP3D_APP}"
@@ -163,6 +175,7 @@ Info "   CI.....................${CI}"
 [ -n "${GITHUB}" ] && Info "   GITHUB.................${GITHUB}" || :
 [ -n "${LP3D_BRANCH}" ] && Info "   LP3D_BRANCH............${LP3D_BRANCH}" || :
 [ -n "${LP3D_COMMIT}" ] && Info "   LP3D_COMMIT............${LP3D_COMMIT}" || :
+#  [ -n "${LP3D_GIT}" ] && Info "   LP3D_GIT...............${LP3D_GIT}" || :
 fi
 Info "   UPDATE_OBS_ALL_DEPS....${UPDATE_OBS_ALL_DEPS}"
 
@@ -230,7 +243,7 @@ EOF
 
 if [ -f "${FILE}" ];
 then
-    Info "$((LP3D_CMD_COUNT += 1)). create version.info    - insert version info   [$FILE]";
+    Info "$((LP3D_CMD_COUNT += 1)). create version.info    - insert version info   [${FILE}]";
 else
     Info "   ERROR - version info   - file not found";
 fi
@@ -260,7 +273,7 @@ fi
 
 FILE="$LP3D_PWD/docs/RELEASE_NOTES.html"
 [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)). update RELEASE_NOTES   - build version         [$FILE]" || :
+Info "$((LP3D_CMD_COUNT += 1)). update RELEASE_NOTES   - build version         [${FILE}]" || :
 LineToReplace=83
 StringToReplace="  <li><code><h4>LPub3D ${LP3D_BUILD_VERSION}</h4></code></li>"
 
@@ -278,7 +291,7 @@ fi
 
 FILE="$LP3D_PWD/docs/README.txt"
 [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)). update README.txt      - build version         [$FILE]" || :
+Info "$((LP3D_CMD_COUNT += 1)). update README.txt      - build version         [${FILE}]" || :
 LineToReplace=1                  # LPub3D 2.0.21.59.126...
 if [[ -f "${FILE}" && -r "${FILE}" ]]
 then
@@ -294,7 +307,7 @@ fi
 
 FILE="$(realpath $LP3D_PWD/../README.md)"
 [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)). update README.md       - update last edit date [$FILE]" || :
+Info "$((LP3D_CMD_COUNT += 1)). update README.md       - update last edit date [${FILE}]" || :
 LastEdit="\[gh-maintained-url\]: https:\/\/github.com\/trevorsandy\/lpub3d-ci\/projects\/1 \"Last edited ${LP3D_LAST_EDIT}\""
 if [[ -f "${FILE}" && -r "${FILE}" ]]
 then
@@ -310,7 +323,7 @@ fi
 
 FILE="$LP3D_PWD/lpub3d.desktop"
 [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)). update desktop config  - add version suffix    [$FILE]" || :
+Info "$((LP3D_CMD_COUNT += 1)). update desktop config  - add version suffix    [${FILE}]" || :
 if [[ -f "${FILE}" && -r "${FILE}" ]]
 then
     if [ "$LP3D_OS" = Darwin ]
@@ -325,23 +338,21 @@ fi
 
 FILE="$LP3D_PWD/lpub3d.appdata.xml"
 [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)). update appdata info    - update binary version [$FILE]" || :
+Info "$((LP3D_CMD_COUNT += 1)). update appdata info    - update binary version [${FILE}]" || :
 if [[ -f "${FILE}" && -r "${FILE}" ]]
 then
     if [ "$LP3D_OS" = Darwin ]
     then
         sed -i "" -e "s/.*<binary>lpub3d.*/            <binary>lpub3d${LP3D_APP_VER_SUFFIX}<\/binary>/" "${FILE}"
-
     else
         sed -i -e "s/.*<binary>lpub3d.*/            <binary>lpub3d${LP3D_APP_VER_SUFFIX}<\/binary>/" "${FILE}" "${FILE}"
-        # perform release update when the last commit is an annotated tag else perform a continuous build update
-        last_commit_sha=$(cd $LP3D_PWD/.. && git rev-parse HEAD) >/dev/null 2>&1
-        last_annotated_tag_sha=$(cd $LP3D_PWD/.. && git rev-list -n 1 $(git describe --abbrev=0)) >/dev/null 2>&1
-        Info "$((LP3D_CMD_COUNT += 1)). update appdata info    - add version and date  [$FILE]" || :
+        Info "$((LP3D_CMD_COUNT += 1)). update appdata info    - add version and date  [${FILE}]" || :
         sed -i -e "0,/.*<release version=.*/{s/.*<release version=.*/            <release version=\"${LP3D_APP_VERSION}\" date=\"$(date "+%Y-%m-%d")\">/}" "${FILE}"
-        if [ "${last_commit_sha}" = "${last_annotated_tag_sha}" ]; then this_is_a_release_build=1; fi
-        Info "   update appdata release - compare last sha hash [commit: ${last_commit_sha:0:8}, annotated tag: ${last_annotated_tag_sha:0:8}]"
-        if [ -n "$this_is_a_release_build" ]
+        if [ "${lp3d_option}" = "queries" ]
+        then
+            Info "   update appdata release - compare last sha hash [commit: ${last_commit_sha:0:8}, annotated tag: ${last_annotated_tag_sha:0:8}]"
+        fi
+        if [ "${LP3D_RELEASE_BUILD}" -eq 1 ]
         then
             sed -i -e "0,/.*<p>LPub3D.*/{s/.*<p>LPub3D.*/                    <p>LPub3D $(date "+%d.%m.%Y") v${LP3D_VERSION} Release Build./}" "${FILE}"
         else
@@ -354,7 +365,7 @@ fi
 
 FILE="$LP3D_PWD/docs/lpub3d${LP3D_APP_VER_SUFFIX}.1"
 [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)). update man page        - add version suffix    [$FILE]" || :
+Info "$((LP3D_CMD_COUNT += 1)). update man page        - add version suffix    [${FILE}]" || :
 FILE_TEMPLATE=`ls $LP3D_PWD/docs/lpub3d.*` >/dev/null 2>&1
 if [ -f ${FILE_TEMPLATE} ];
 then
@@ -376,76 +387,91 @@ else
     Info "   Error: Cannot read ${FILE} (be sure ${FILE_TEMPLATE} exsit) from ${LP3D_CALL_DIR}"
 fi
 
-FILE="$LP3D_CONFIG_DIR/debian/changelog"
+FILEPATH=${LP3D_OBS_DEPS_DIR}
+for FILENAME in PKGBUILD PKGBUILD PKGBUILD-qt5; do
+    FILE="${FILEPATH}/$FILENAME"
+    [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
+    Info "$((LP3D_CMD_COUNT += 1)).update ${FILENAME}        - add version           [${FILE}]" || :
+    if [[ -f "${FILE}" && -r "${FILE}" ]]
+    then
+        if [ "$LP3D_OS" = Darwin ]
+        then
+            sed -i "" -e "s/^# Last Update:.*/# Last Update: $(date "+%B %d, %Y")/g" \
+                      -e "s/^pkgver.*/pkgver=${LP3D_APP_VERSION}/" "${FILE}"
+        else
+            sed -i -e "s/^# Last Update:.*/# Last Update: $(date "+%B %d, %Y")/g" \
+                   -e "s/^pkgver.*/pkgver=${LP3D_APP_VERSION}/" "${FILE}"
+        fi
+    else
+        Info "   Error: Cannot read ${FILE} from ${LP3D_CALL_DIR}"
+    fi
+    [ "${UPDATE_OBS_ALL_DEPS}" == "No" ] && break || :
+    FILEPATH=${LP3D_OBS_ALL_DEPS_DIR}
+done
+
+FILEPATH=${LP3D_OBS_DEPS_DIR}
+for FILENAME in ${LP3D_APP}.spec ${LP3D_APP}.spec ${LP3D_APP}-qt5.spec; do
+    FILE="${FILEPATH}/${FILENAME}"
+    [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
+    Info "$((LP3D_CMD_COUNT += 1)).update ${FILENAME}  - add version and date  [${FILE}]" || :
+    if [[ -f "${FILE}" && -r "${FILE}" ]]
+    then
+        if [ "$LP3D_OS" = Darwin ]
+        then
+            sed -i "" -e "s/^# Last Update:.*/# Last Update: $(date "+%B %d, %Y")/g" \
+                      -e "s/^Version:.*/Version: ${LP3D_APP_VERSION}/" \
+                      -e "s/.*trevor\.dot\.sandy\.at\.gmail\.dot\.com.*/* ${LP3D_CHANGE_DATE} - trevor\.dot\.sandy\.at\.gmail\.dot\.com ${LP3D_APP_VERSION}/" "${FILE}"
+        else
+            sed -i -e "s/^# Last Update:.*/# Last Update: $(date "+%B %d, %Y")/g" \
+                   -e "s/^Version:.*/Version: ${LP3D_APP_VERSION}/" \
+                   -e "s/.*trevor\.dot\.sandy\.at\.gmail\.dot\.com.*/* ${LP3D_CHANGE_DATE} - trevor\.dot\.sandy\.at\.gmail\.dot\.com ${LP3D_APP_VERSION}/" "${FILE}"
+        fi
+    else
+        Info "   Error: Cannot read ${FILE} from ${LP3D_CALL_DIR}"
+    fi
+    [ "${UPDATE_OBS_ALL_DEPS}" = "No" ] && break || :
+    FILEPATH=${LP3D_OBS_ALL_DEPS_DIR}
+done
+
+FILEPATH=${LP3D_OBS_DEPS_DIR}
+for FILENAME in ${LP3D_APP}.dsc ${LP3D_APP}.dsc ${LP3D_APP}-qt5.dsc; do
+    FILE="${FILEPATH}/debian/${FILENAME}"
+    [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
+    Info "$((LP3D_CMD_COUNT += 1)).update ${FILENAME}   - add version           [${FILE}]" || :
+    if [[ -f "${FILE}" && -r "${FILE}" ]]
+    then
+        if [ "$LP3D_OS" = Darwin ]
+        then
+            sed -i "" "s/^Version:.*/Version: ${LP3D_APP_VERSION}/" "${FILE}"
+        else
+            sed -i "s/^Version:.*/Version: ${LP3D_APP_VERSION}/" "${FILE}"
+        fi
+    else
+        Info "   Error: Cannot read ${FILE} from ${LP3D_CALL_DIR}"
+    fi
+    [ "${UPDATE_OBS_ALL_DEPS}" = "No" ] && break || :
+    FILEPATH=${LP3D_OBS_ALL_DEPS_DIR}
+done
+
+FILE="${LP3D_OBS_DEPS_DIR}/debian/changelog"
 [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)).create changelog       - add version and date  [$FILE]" || :
+Info "$((LP3D_CMD_COUNT += 1)).create changelog       - add version and date  [${FILE}]" || :
 if [[ -f "${FILE}" && -r "${FILE}" ]]
 then
-    rm ${FILE}
+    rm -f ${FILE}
 fi
 cat <<EOF >${FILE}
-${LP3D_APP} (${LP3D_APP_VERSION}) debian; urgency=medium
+${LP3D_APP} (${LP3D_APP_VERSION}) stable; urgency=low
 
-  * LPub3D version ${LP3D_APP_VERSION_LONG} for Linux
+  * LPub3D version ${LP3D_APP_VERSION_LONG} for Debian Linux
+  * See RELEASE_NOTES.html for enhancements, changes and fixes
 
  -- Trevor SANDY <trevor.sandy@gmail.com>  ${LP3D_CHANGE_DATE_LONG}
 EOF
 
-FILE="$LP3D_CONFIG_DIR/PKGBUILD"
+FILE="${LP3D_OBS_DEPS_DIR}/debian/rules"
 [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)).update PKGBUILD        - add version           [$FILE]" || :
-if [[ -f "${FILE}" && -r "${FILE}" ]]
-then
-    if [ "$LP3D_OS" = Darwin ]
-    then
-        sed -i "" -e "s/^# Last Update:.*/# Last Update: $(date "+%B %d, %Y")/g" \
-                  -e "s/^pkgver.*/pkgver=${LP3D_APP_VERSION}/" "${FILE}"
-    else
-        sed -i -e "s/^# Last Update:.*/# Last Update: $(date "+%B %d, %Y")/g" \
-               -e "s/^pkgver.*/pkgver=${LP3D_APP_VERSION}/" "${FILE}"
-    fi
-else
-    Info "   Error: Cannot read ${FILE} from ${LP3D_CALL_DIR}"
-fi
-
-FILE="$LP3D_CONFIG_DIR/${LP3D_APP}.spec"
-[ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)).update ${LP3D_APP}.spec  - add version and date  [$FILE]" || :
-if [[ -f "${FILE}" && -r "${FILE}" ]]
-then
-    if [ "$LP3D_OS" = Darwin ]
-    then
-        sed -i "" -e "s/^# Last Update:.*/# Last Update: $(date "+%B %d, %Y")/g" \
-                  -e "s/^Version:.*/Version: ${LP3D_APP_VERSION}/" \
-                  -e "s/.*trevor\.dot\.sandy\.at\.gmail\.dot\.com.*/* ${LP3D_CHANGE_DATE} - trevor\.dot\.sandy\.at\.gmail\.dot\.com ${LP3D_APP_VERSION}/" "${FILE}"
-
-    else
-        sed -i -e "s/^# Last Update:.*/# Last Update: $(date "+%B %d, %Y")/g" \
-               -e "s/^Version:.*/Version: ${LP3D_APP_VERSION}/" \
-               -e "s/.*trevor\.dot\.sandy\.at\.gmail\.dot\.com.*/* ${LP3D_CHANGE_DATE} - trevor\.dot\.sandy\.at\.gmail\.dot\.com ${LP3D_APP_VERSION}/" "${FILE}"
-    fi
-else
-    Info "   Error: Cannot read ${FILE} from ${LP3D_CALL_DIR}"
-fi
-
-FILE="$LP3D_CONFIG_DIR/debian/${LP3D_APP}.dsc"
-[ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)).update ${LP3D_APP}.dsc   - add version           [$FILE]" || :
-if [[ -f "${FILE}" && -r "${FILE}" ]]
-then
-    if [ "$LP3D_OS" = Darwin ]
-    then
-        sed -i "" "s/^Version:.*/Version: ${LP3D_APP_VERSION}/" "${FILE}"
-    else
-        sed -i "s/^Version:.*/Version: ${LP3D_APP_VERSION}/" "${FILE}"
-    fi
-else
-    Info "   Error: Cannot read ${FILE} from ${LP3D_CALL_DIR}"
-fi
-
-FILE="$(realpath $LP3D_PWD/../builds/linux/obs/debian/rules)"
-[ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)).update debian rules    - add version suffix    [$FILE]" || :
+Info "$((LP3D_CMD_COUNT += 1)).update debian rules    - add version suffix    [${FILE}]" || :
 LP3D_OS_ARCH=32 && \
 [[ "$(uname -m)" = "x86_64" || "$(uname -m)" = "aarch64" ]] && \
 LP3D_OS_ARCH=64
@@ -465,7 +491,7 @@ fi
 
 FILE="$(realpath $LP3D_PWD/../gitversion.pri)"
 [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)).update gitversion pri  - add version and revision [$FILE]" || :
+Info "$((LP3D_CMD_COUNT += 1)).update gitversion pri  - add version and revision [${FILE}]" || :
 if [[ -f "${FILE}" && -r "${FILE}" ]]
 then
     if test -n "$LP3D_VER_SUFFIX"; then
@@ -489,7 +515,7 @@ fi
 
 FILE="$(realpath $LP3D_PWD/../mainApp/extras/LPub3D_Npp_UDL.xml)"
 [ -z "$LP3D_NO_CONFIG_DISPLAY" ] && \
-Info "$((LP3D_CMD_COUNT += 1)).update Notepad-pp UDL  - update version and date  [$FILE]" || :
+Info "$((LP3D_CMD_COUNT += 1)).update Notepad-pp UDL  - update version and date  [${FILE}]" || :
 if [[ -f "${FILE}" && -r "${FILE}" ]]
 then
     LP3D_UDL_APP_VERSION="${LP3D_VERSION}.${LP3D_VER_REVISION}.${LP3D_VER_BUILD}"
@@ -507,7 +533,7 @@ fi
 
 # ..............................
 else # _EXPORT_CONFIG_ONLY_ set, skip config files update
-    Info "   Skip config files update (Config on export only)."
+    Info "   Skip config files update (Export config only)."
 fi
 # ..............................
 
